==> gnome-commander_1.2.8.17.orig.tar.xz: gnome-commander-1.2.8.17/src/gnome-cmd-con-home.h <==
/*
    GNOME Commander - A GNOME based file manager
    Copyright (C) 2001-2006 Marcus Bjurman
    Copyright (C) 2007-2012 Piotr Eljasiak
    Copyright (C) 2013-2014 Uwe Scholz

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef __GNOME_CMD_CON_HOME_H__
#define __GNOME_CMD_CON_HOME_H__

#include "gnome-cmd-con.h"

#define GNOME_CMD_CON_HOME(obj) \
    GTK_CHECK_CAST (obj, gnome_cmd_con_home_get_type (), GnomeCmdConHome)
#define GNOME_CMD_CON_HOME_CLASS(klass) \
    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_con_home_get_type (), GnomeCmdConHomeClass)
#define GNOME_CMD_IS_CON_HOME(obj) \
    GTK_CHECK_TYPE (obj, gnome_cmd_con_home_get_type ())


struct GnomeCmdConHome
{
    GnomeCmdCon parent;
};


struct GnomeCmdConHomeClass
{
    GnomeCmdConClass parent_class;
};


GtkType gnome_cmd_con_home_get_type ();

GnomeCmdCon *gnome_cmd_con_home_new ();

#endif // __GNOME_CMD_CON_HOME_H__

==> gnome-commander-1.4.2.tar.xz: gnome-commander-1.4.2/src/gnome-cmd-con-home.h <==
/*
    GNOME Commander - A GNOME based file manager
    Copyright (C) 2001-2006 Marcus Bjurman
    Copyright (C) 2007-2012 Piotr Eljasiak
    Copyright (C) 2013-2014 Uwe Scholz

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef __GNOME_CMD_CON_HOME_H__
#define __GNOME_CMD_CON_HOME_H__

#include "gnome-cmd-con.h"

#define GNOME_CMD_TYPE_CON_HOME              (gnome_cmd_con_home_get_type ())
#define GNOME_CMD_CON_HOME(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GNOME_CMD_TYPE_CON_HOME, GnomeCmdConHome))
#define GNOME_CMD_CON_HOME_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass), GNOME_CMD_TYPE_CON_HOME, GnomeCmdConHomeClass))
#define GNOME_CMD_IS_CON_HOME(obj)           (G_TYPE_CHECK_INSTANCE_TYPE((obj), GNOME_CMD_TYPE_CON_HOME))
#define GNOME_CMD_IS_CON_HOME_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_CMD_TYPE_CON_HOME))
#define GNOME_CMD_CON_HOME_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GNOME_CMD_TYPE_CON_HOME, GnomeCmdConHomeClass))


struct GnomeCmdConHome
{
    GnomeCmdCon parent;
};


struct GnomeCmdConHomeClass
{
    GnomeCmdConClass parent_class;
};


GtkType gnome_cmd_con_home_get_type ();

GnomeCmdCon *gnome_cmd_con_home_new ();

#endif // __GNOME_CMD_CON_HOME_H__
